import execjs
from urllib import request, parse


def query_encode(query: str) -> str:
    """
    :param query:
    :return:
    """
    if isinstance(query, str):
        return parse.quote(query)
    raise f"query is not string!"


def get_x96(token, search_api):
    with open('./KnowAlmost/static/x-zse-96.js', 'r', encoding='utf-8') as f:
        js = f.read()
    etx = execjs.compile(js)
    return etx.call('get_xzse96', token, search_api)



"""Simple reader that reads wikipedia."""
from typing import Any, List

from llama_index.readers.base import BaseReader
from llama_index.readers.schema.base import Document


class KnowAlmostReader(BaseReader):
    """KnowAlmost reader.

    Reads a page.

    """

    def load_data(self, query: str, token, **load_kwargs: Any) -> List[Document]:
        """Load data from the input directory.

        Args:
            pages (List[str]): List of pages to read.

        """
        from setup import api

        results = []
        page_content = api.request(query=query, token=token).content
        results.append(Document(page_content))
        return results

# d_c0 = 'APAdAlwbIBWPThzJMZJuMEoPksQPWXxgiTc=|1655711908'
#
# s = z.load_data("小沈阳", d_c0)
# print(s)


# KnowAlmost
# See LICENSE for details.

"""
KnowAlmost API library
"""
__version__ = '1.0.1'
__author__ = ''

import setuptools

with open("README.md", "r") as fh:
  long_description = fh.read()

setuptools.setup(
  name="KnowAlmost",
  version="0.0.1",
  author="W·Wen",
  author_email="23626319@qq.com",
  description="KnowAlmost is a package that encapsulates the KnowAlmost api. I often use it in competitions and work. More skills are on the way!",
  long_description=long_description,
  long_description_content_type="text/markdown",
  packages=setuptools.find_packages(),
  classifiers=[
  "Programming Language :: Python :: 3",
  "License :: OSI Approved :: MIT License",
  "Operating System :: OS Independent",
  ],
)


# requests

LIST_PARAMS = {
    "gk_version": "gz-gaokao",
    "t": "general",
    "q": "",
    "correction": "1",
    "offset": "0",
    "limit": "20",
    "filter_fields": "",
    "lc_idx": "0",
    "show_all_topics": "0",
    "search_source": "Normal"
}

LIST_HEADERS = {
    "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64)"
                  " AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36",
    "x-api-version": "3.0.91",
    "x-zse-93": "101_3_3.0",
}
